/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_H5XeTjmh);
  numBytes += sPhasor_k_init(&sPhasor_vrDpKI9U, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_vG9cSfhg);
  numBytes += sRPole_init(&sRPole_7VWBboIa);
  numBytes += sRPole_init(&sRPole_7Z7xzWbX);
  numBytes += sTabhead_init(&sTabhead_NokGIJA4, &hTable_gkNuhvIQ);
  numBytes += sTabread_init(&sTabread_d2QmtIaB, &hTable_gkNuhvIQ, false);
  numBytes += sTabread_init(&sTabread_7HqjlehQ, &hTable_gkNuhvIQ, false);
  numBytes += sLine_init(&sLine_O5aJlkSe);
  numBytes += sTabhead_init(&sTabhead_VQB5hCN4, &hTable_5tZRFMle);
  numBytes += sTabread_init(&sTabread_lhIZ0Qae, &hTable_5tZRFMle, false);
  numBytes += sTabread_init(&sTabread_lUyDBMHk, &hTable_5tZRFMle, false);
  numBytes += sLine_init(&sLine_bEoaNuAq);
  numBytes += sTabwrite_init(&sTabwrite_GosVYE3c, &hTable_5tZRFMle);
  numBytes += sTabwrite_init(&sTabwrite_6v0HpaE7, &hTable_gkNuhvIQ);
  numBytes += cVar_init_f(&cVar_rPgiycZu, 0.0f);
  numBytes += cVar_init_f(&cVar_pu46J7Si, 0.0f);
  numBytes += cVar_init_f(&cVar_r3HZ0Nq9, 0.0f);
  numBytes += cVar_init_f(&cVar_mKn1nTYQ, 0.0f);
  numBytes += cVar_init_s(&cVar_ed5Izvz3, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_XzBwbZzu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Cg2JyDh7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ObAyTIYu, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_bTNfXqb8, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_wEXjhUlj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9qd6ZRxv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nqJ1JYVW, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_bewQbi2k, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0Fdrb90Y, 0.0f);
  numBytes += hTable_init(&hTable_5tZRFMle, 256);
  numBytes += cDelay_init(this, &cDelay_S9SW4WFe, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9QCuWZQ3, 0.0f);
  numBytes += hTable_init(&hTable_gkNuhvIQ, 256);
  numBytes += cVar_init_f(&cVar_B7L4Zra2, 14.0f);
  numBytes += cBinop_init(&cBinop_Z7jcIj2v, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5UOaadCZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KLLiSkrd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_QxMJElj4, 14.0f);
  numBytes += cBinop_init(&cBinop_FwAVghvS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tIhnYnai, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xNFhkJPk, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_9zWPZqlC, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_VRzEo9dI, 1, -1);
  numBytes += cVar_init_f(&cVar_cw1F8FrX, 0.2f);
  numBytes += cSlice_init(&cSlice_2Zom1BYS, 1, -1);
  numBytes += cVar_init_f(&cVar_vYzkYGCs, 0.0f);
  numBytes += cSlice_init(&cSlice_DE7NsDxv, 1, -1);
  numBytes += cVar_init_f(&cVar_fSDeWdPa, 2.0f);
  numBytes += cSlice_init(&cSlice_F69t0Ibq, 1, -1);
  numBytes += cVar_init_f(&cVar_CHykSLZW, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_5tZRFMle);
  hTable_free(&hTable_gkNuhvIQ);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_5tZRFMle; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_gkNuhvIQ; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zY8G0kAG_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DuGJWGN3_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dq0NvF3p_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VlQPinnH_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pbPY5Ht2_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_smofkpAP_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GN5Vb0xg_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QiRM4lOm_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_azEPa7bi_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_rPgiycZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dn9qnKYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_pu46J7Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qHir02ep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_r3HZ0Nq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9VX32qLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_mKn1nTYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ug14GO3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_8R8XjZeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oKgmpINz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_oKgmpINz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_vrDpKI9U, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_9RJebSkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IxFUHeIS_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_IxFUHeIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_s5cdX8r9_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_ed5Izvz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9E331nzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_TFaLQtas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yldJp49Q_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XzBwbZzu, m);
}

void Heavy_WSTD_FLANGR::cBinop_s5cdX8r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cg2JyDh7, m);
}

void Heavy_WSTD_FLANGR::cMsg_9E331nzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TFaLQtas_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yldJp49Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ObAyTIYu, m);
}

void Heavy_WSTD_FLANGR::cMsg_iCxsOMxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IX9eMspY_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_IX9eMspY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0hTNt6EL_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_bTNfXqb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t9uXeEB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_o6kmqph7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dSrkzkbe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wEXjhUlj, m);
}

void Heavy_WSTD_FLANGR::cBinop_0hTNt6EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9qd6ZRxv, m);
}

void Heavy_WSTD_FLANGR::cMsg_t9uXeEB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o6kmqph7_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_dSrkzkbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nqJ1JYVW, m);
}

void Heavy_WSTD_FLANGR::cBinop_7EQ8cyYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_A59KWAm2_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_A59KWAm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_hChqNLs9_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_2bIzZAVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YY2oYz7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_Ir1dDZpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZ96tacH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_hChqNLs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EYf2yXCH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_EYf2yXCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oR48gkQc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_foNODJrY_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_foNODJrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ft8ttdUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_oR48gkQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_i3u8qSZR_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_i3u8qSZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cFF1F4Pk_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ft8ttdUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_y13SiuKm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_y13SiuKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CIjOevV1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_cFF1F4Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_2bIzZAVF_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_CIjOevV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Ir1dDZpi_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_a9Mr3bj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wkXEt7Qz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_wkXEt7Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IeegYeSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_yfY1Qshp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I48RdezR_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_I48RdezR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_c9hNP97w_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_bewQbi2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bewQbi2k, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Fdrb90Y, 0, m, &cDelay_0Fdrb90Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bewQbi2k, 0, m, &cDelay_bewQbi2k_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GosVYE3c, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_0Fdrb90Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Fdrb90Y, m);
  cMsg_3GzP8BoH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_JF5voKSb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4B2wYEKc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_fugdGPEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yzrljryC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_5tZRFMle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H3u4HmtT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bewQbi2k, 2, m, &cDelay_bewQbi2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Og6PJJ3l_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_yzrljryC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5tZRFMle, 0, m, &hTable_5tZRFMle_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_c9hNP97w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_fugdGPEi_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_3GzP8BoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5tZRFMle, 0, m, &hTable_5tZRFMle_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_Og6PJJ3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bewQbi2k, 0, m, &cDelay_bewQbi2k_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_H3u4HmtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Fdrb90Y, 2, m, &cDelay_0Fdrb90Y_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_4B2wYEKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GosVYE3c, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_RzBS9oC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Jg6YQQ6l_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_Jg6YQQ6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9wxbdzTj_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_S9SW4WFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S9SW4WFe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9QCuWZQ3, 0, m, &cDelay_9QCuWZQ3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S9SW4WFe, 0, m, &cDelay_S9SW4WFe_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6v0HpaE7, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_9QCuWZQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9QCuWZQ3, m);
  cMsg_cFpH8hAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_3hnvVkiN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ROnjRc6j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_nXrtFsnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YSO2dr49_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_gkNuhvIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_okbSs8Lx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S9SW4WFe, 2, m, &cDelay_S9SW4WFe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cfpY5Wvh_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_YSO2dr49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gkNuhvIQ, 0, m, &hTable_gkNuhvIQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9wxbdzTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_nXrtFsnr_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cFpH8hAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gkNuhvIQ, 0, m, &hTable_gkNuhvIQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_cfpY5Wvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S9SW4WFe, 0, m, &cDelay_S9SW4WFe_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_okbSs8Lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9QCuWZQ3, 2, m, &cDelay_9QCuWZQ3_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ROnjRc6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6v0HpaE7, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_B7L4Zra2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z7jcIj2v, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z7jcIj2v_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_5Ibiq7Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o5QdrkXN_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_o5QdrkXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oELorjYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Z7jcIj2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kU7LKBql_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nnNPNoPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z7jcIj2v, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z7jcIj2v_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_oELorjYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nnNPNoPl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_kU7LKBql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GidwjyR4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GidwjyR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5Rt9IUlM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KLLiSkrd, m);
}

void Heavy_WSTD_FLANGR::cBinop_5Rt9IUlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5UOaadCZ, m);
}

void Heavy_WSTD_FLANGR::cVar_QxMJElj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FwAVghvS, HV_BINOP_MULTIPLY, 0, m, &cBinop_FwAVghvS_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_zKoAunPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GRU62UUn_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_GRU62UUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C7w7dQ5L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_FwAVghvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MwsqyiNH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_MMLvRylN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FwAVghvS, HV_BINOP_MULTIPLY, 1, m, &cBinop_FwAVghvS_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_C7w7dQ5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MMLvRylN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_MwsqyiNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x3eIYy4p_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_x3eIYy4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5PoXNtqk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xNFhkJPk, m);
}

void Heavy_WSTD_FLANGR::cBinop_5PoXNtqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tIhnYnai, m);
}

void Heavy_WSTD_FLANGR::cMsg_IeegYeSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vG9cSfhg, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_pPXkuJ3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_Kp0qGEos_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_pQ0WTkDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_pPXkuJ3o_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_AwqvfdYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2mBJf6lt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_RKV2fBpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_F8d1I4Yv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_F8d1I4Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9zWPZqlC, HV_BINOP_MULTIPLY, 1, m, &cBinop_9zWPZqlC_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2mBJf6lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_RKV2fBpo_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9zWPZqlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tFEc9zjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Kp0qGEos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9zWPZqlC, HV_BINOP_MULTIPLY, 0, m, &cBinop_9zWPZqlC_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_tFEc9zjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bEoaNuAq, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_DVARFOqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_OGH8a2ur_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_OGH8a2ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AwqvfdYU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pQ0WTkDU_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_9BE813Ro_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VRzEo9dI, 0, m, &cSlice_VRzEo9dI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_H7loRvY3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_VRzEo9dI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0FeWPVuG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0FeWPVuG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_cw1F8FrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0FeWPVuG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_0FeWPVuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_smofkpAP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_H7loRvY3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2Zom1BYS, 0, m, &cSlice_2Zom1BYS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_C4Bw03ZP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_2Zom1BYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S8zHLWzS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S8zHLWzS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_vYzkYGCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S8zHLWzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_S8zHLWzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pbPY5Ht2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_C4Bw03ZP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DE7NsDxv, 0, m, &cSlice_DE7NsDxv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PpA6nPPP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_DE7NsDxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zjv3NC5F_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zjv3NC5F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_fSDeWdPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zjv3NC5F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_Zjv3NC5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QiRM4lOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_PpA6nPPP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F69t0Ibq, 0, m, &cSlice_F69t0Ibq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_F69t0Ibq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UmaE7NP6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UmaE7NP6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_CHykSLZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UmaE7NP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_UmaE7NP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GN5Vb0xg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_YY2oYz7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O5aJlkSe, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_yZ96tacH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H5XeTjmh, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Ug14GO3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9BE813Ro_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Dn9qnKYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9BE813Ro_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_qHir02ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9BE813Ro_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_9VX32qLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9BE813Ro_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_OvbnhIDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mKn1nTYQ, 0, m, &cVar_mKn1nTYQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_a09ZRVca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rPgiycZu, 0, m, &cVar_rPgiycZu_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_CXoED1XY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r3HZ0Nq9, 0, m, &cVar_r3HZ0Nq9_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_QiRM4lOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_8R8XjZeL_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_pbPY5Ht2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DVARFOqJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_azEPa7bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Ibiq7Db_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B7L4Zra2, 0, m, &cVar_B7L4Zra2_sendMessage);
  cMsg_zKoAunPn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QxMJElj4, 0, m, &cVar_QxMJElj4_sendMessage);
  cMsg_yfY1Qshp_sendMessage(_c, 0, m);
  cMsg_RzBS9oC6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cw1F8FrX, 0, m, &cVar_cw1F8FrX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vYzkYGCs, 0, m, &cVar_vYzkYGCs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fSDeWdPa, 0, m, &cVar_fSDeWdPa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CHykSLZW, 0, m, &cVar_CHykSLZW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ed5Izvz3, 0, m, &cVar_ed5Izvz3_sendMessage);
  cMsg_9RJebSkx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bTNfXqb8, 0, m, &cVar_bTNfXqb8_sendMessage);
  cMsg_iCxsOMxz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_GN5Vb0xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7EQ8cyYy_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_smofkpAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_a9Mr3bj5_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_VlQPinnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pu46J7Si, 0, m, &cVar_pu46J7Si_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Dq0NvF3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_OvbnhIDh_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_DuGJWGN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CXoED1XY_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_zY8G0kAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_a09ZRVca_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_H5XeTjmh, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_vrDpKI9U, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_vG9cSfhg, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_KLLiSkrd, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5UOaadCZ, VOf(Bf3));
    __hv_rpole_f(&sRPole_7VWBboIa, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_xNFhkJPk, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_tIhnYnai, VOf(Bf4));
    __hv_rpole_f(&sRPole_7Z7xzWbX, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_NokGIJA4, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Cg2JyDh7, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_ObAyTIYu, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_XzBwbZzu, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_d2QmtIaB, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_7HqjlehQ, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_O5aJlkSe, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_VQB5hCN4, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_9qd6ZRxv, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_nqJ1JYVW, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_wEXjhUlj, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_lhIZ0Qae, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_lUyDBMHk, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_bEoaNuAq, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_GosVYE3c, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_6v0HpaE7, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
