/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvControlDelay.h"
#include "HvSignalPhasor.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvSignalTabwrite.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_rPgiycZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pu46J7Si_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r3HZ0Nq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mKn1nTYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8R8XjZeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oKgmpINz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9RJebSkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IxFUHeIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ed5Izvz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TFaLQtas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5cdX8r9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9E331nzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yldJp49Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iCxsOMxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IX9eMspY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bTNfXqb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_o6kmqph7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hTNt6EL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t9uXeEB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dSrkzkbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7EQ8cyYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A59KWAm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2bIzZAVF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ir1dDZpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hChqNLs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EYf2yXCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_foNODJrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oR48gkQc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i3u8qSZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ft8ttdUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y13SiuKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cFF1F4Pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CIjOevV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a9Mr3bj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wkXEt7Qz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yfY1Qshp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I48RdezR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bewQbi2k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0Fdrb90Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JF5voKSb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_fugdGPEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5tZRFMle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yzrljryC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c9hNP97w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3GzP8BoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Og6PJJ3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H3u4HmtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4B2wYEKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RzBS9oC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Jg6YQQ6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_S9SW4WFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9QCuWZQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3hnvVkiN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nXrtFsnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_gkNuhvIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YSO2dr49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9wxbdzTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cFpH8hAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cfpY5Wvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_okbSs8Lx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ROnjRc6j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B7L4Zra2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Ibiq7Db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_o5QdrkXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z7jcIj2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnNPNoPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oELorjYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kU7LKBql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GidwjyR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Rt9IUlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QxMJElj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zKoAunPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GRU62UUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FwAVghvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMLvRylN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C7w7dQ5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MwsqyiNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3eIYy4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5PoXNtqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IeegYeSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pPXkuJ3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pQ0WTkDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AwqvfdYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RKV2fBpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F8d1I4Yv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2mBJf6lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9zWPZqlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kp0qGEos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tFEc9zjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DVARFOqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OGH8a2ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9BE813Ro_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VRzEo9dI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cw1F8FrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0FeWPVuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_H7loRvY3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2Zom1BYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vYzkYGCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S8zHLWzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_C4Bw03ZP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DE7NsDxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fSDeWdPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Zjv3NC5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PpA6nPPP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_F69t0Ibq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CHykSLZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UmaE7NP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YY2oYz7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yZ96tacH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ug14GO3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dn9qnKYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qHir02ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9VX32qLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OvbnhIDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a09ZRVca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CXoED1XY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QiRM4lOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pbPY5Ht2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_azEPa7bi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GN5Vb0xg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_smofkpAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VlQPinnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Dq0NvF3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DuGJWGN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zY8G0kAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_H5XeTjmh;
  SignalPhasor sPhasor_vrDpKI9U;
  SignalLine sLine_vG9cSfhg;
  SignalRPole sRPole_7VWBboIa;
  SignalRPole sRPole_7Z7xzWbX;
  SignalTabhead sTabhead_NokGIJA4;
  SignalTabread sTabread_d2QmtIaB;
  SignalTabread sTabread_7HqjlehQ;
  SignalLine sLine_O5aJlkSe;
  SignalTabhead sTabhead_VQB5hCN4;
  SignalTabread sTabread_lhIZ0Qae;
  SignalTabread sTabread_lUyDBMHk;
  SignalLine sLine_bEoaNuAq;
  SignalTabwrite sTabwrite_GosVYE3c;
  SignalTabwrite sTabwrite_6v0HpaE7;
  ControlVar cVar_rPgiycZu;
  ControlVar cVar_pu46J7Si;
  ControlVar cVar_r3HZ0Nq9;
  ControlVar cVar_mKn1nTYQ;
  ControlBinop cBinop_8R8XjZeL;
  ControlBinop cBinop_oKgmpINz;
  ControlVar cVar_ed5Izvz3;
  ControlBinop cBinop_s5cdX8r9;
  ControlBinop cBinop_yldJp49Q;
  SignalVarf sVarf_XzBwbZzu;
  SignalVarf sVarf_Cg2JyDh7;
  SignalVarf sVarf_ObAyTIYu;
  ControlVar cVar_bTNfXqb8;
  ControlBinop cBinop_0hTNt6EL;
  ControlBinop cBinop_dSrkzkbe;
  SignalVarf sVarf_wEXjhUlj;
  SignalVarf sVarf_9qd6ZRxv;
  SignalVarf sVarf_nqJ1JYVW;
  ControlBinop cBinop_7EQ8cyYy;
  ControlBinop cBinop_A59KWAm2;
  ControlBinop cBinop_hChqNLs9;
  ControlBinop cBinop_EYf2yXCH;
  ControlBinop cBinop_i3u8qSZR;
  ControlBinop cBinop_y13SiuKm;
  ControlBinop cBinop_cFF1F4Pk;
  ControlBinop cBinop_CIjOevV1;
  ControlBinop cBinop_a9Mr3bj5;
  ControlBinop cBinop_wkXEt7Qz;
  ControlDelay cDelay_bewQbi2k;
  ControlDelay cDelay_0Fdrb90Y;
  ControlBinop cBinop_fugdGPEi;
  HvTable hTable_5tZRFMle;
  ControlBinop cBinop_c9hNP97w;
  ControlDelay cDelay_S9SW4WFe;
  ControlDelay cDelay_9QCuWZQ3;
  ControlBinop cBinop_nXrtFsnr;
  HvTable hTable_gkNuhvIQ;
  ControlBinop cBinop_9wxbdzTj;
  ControlVar cVar_B7L4Zra2;
  ControlBinop cBinop_Z7jcIj2v;
  ControlBinop cBinop_nnNPNoPl;
  SignalVarf sVarf_5UOaadCZ;
  ControlBinop cBinop_kU7LKBql;
  ControlBinop cBinop_GidwjyR4;
  ControlBinop cBinop_5Rt9IUlM;
  SignalVarf sVarf_KLLiSkrd;
  ControlVar cVar_QxMJElj4;
  ControlBinop cBinop_FwAVghvS;
  ControlBinop cBinop_MMLvRylN;
  SignalVarf sVarf_tIhnYnai;
  ControlBinop cBinop_MwsqyiNH;
  ControlBinop cBinop_x3eIYy4p;
  ControlBinop cBinop_5PoXNtqk;
  SignalVarf sVarf_xNFhkJPk;
  ControlBinop cBinop_RKV2fBpo;
  ControlBinop cBinop_F8d1I4Yv;
  ControlBinop cBinop_2mBJf6lt;
  ControlBinop cBinop_9zWPZqlC;
  ControlBinop cBinop_Kp0qGEos;
  ControlBinop cBinop_DVARFOqJ;
  ControlBinop cBinop_OGH8a2ur;
  ControlSlice cSlice_VRzEo9dI;
  ControlVar cVar_cw1F8FrX;
  ControlSlice cSlice_2Zom1BYS;
  ControlVar cVar_vYzkYGCs;
  ControlSlice cSlice_DE7NsDxv;
  ControlVar cVar_fSDeWdPa;
  ControlSlice cSlice_F69t0Ibq;
  ControlVar cVar_CHykSLZW;
  ControlBinop cBinop_OvbnhIDh;
  ControlBinop cBinop_a09ZRVca;
  ControlBinop cBinop_CXoED1XY;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
